@@ -28,7 +28,7 @@ translation_copyrights="English, German: George Ruinelli\n"+\
                                      (u'Français')+": Fred Kwame Ayanful & Guy Roussin\n"+\
                                      "Dutch: Fred Kwame Ayanful\n"+\
                                      "Chinese: "+(u'蒋岚')+" (Peter3316)\n"+\
-                                     "Czech: "+(u'Vít Stanisalv')
+                                     "Czech: "+(u'Vít Stanislav')
 
 #DEFAULT VALUES
 Yscale_Movement_default=20  #Y stretching of yellow movement bars
